Class: Karafka::Web::Pro::Commanding::Commands::Topics::Pause

Inherits:
Base
  • Object
show all
Defined in:
lib/karafka/web/pro/commanding/commands/topics/pause.rb

Overview

Delegates the topic pause request into the topic changes tracker and dispatches the acceptance message back to Kafka. This command pauses all partitions of a given topic within a specific consumer group. Matchers filter which processes handle the command.

Instance Attribute Summary

Attributes inherited from Base

#command

Instance Method Summary collapse

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Karafka::Web::Pro::Commanding::Commands::Base

Instance Method Details

#callObject

Delegates the pause request to async handling



45
46
47
48
49
# File 'lib/karafka/web/pro/commanding/commands/topics/pause.rb', line 45

def call
  Handlers::Topics::Tracker.instance << command

  acceptance(command.to_h)
end