Class: Karafka::Web::Pro::Commanding::Commands::Topics::Resume

Inherits:
Base
  • Object
show all
Defined in:
lib/karafka/web/pro/commanding/commands/topics/resume.rb

Overview

Delegates the topic resume request into the topic changes tracker and dispatches the acceptance message back to Kafka. This command resumes all partitions of a given topic within a specific consumer group. Matchers filter which processes handle the command.

Instance Attribute Summary

Attributes inherited from Base

#command

Instance Method Summary collapse

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Karafka::Web::Pro::Commanding::Commands::Base

Instance Method Details

#callObject

Dispatches the resume request into the appropriate handler and indicates that the resuming is in an acceptance state



45
46
47
48
49
50
# File 'lib/karafka/web/pro/commanding/commands/topics/resume.rb', line 45

def call
  Handlers::Topics::Tracker.instance << command

  # Publish back info on who did this with all the details for inspection
  acceptance(command.to_h)
end