Class: Karafka::Web::Ui::Models::Status::Checks::ProSubscription

Inherits:
Base
  • Object
show all
Defined in:
lib/karafka/web/ui/models/status/checks/pro_subscription.rb

Overview

Checks if Karafka Pro is enabled.

This is an independent, warning-only check. Not having Pro is not an error, but users should be aware that some features may not work without it.

Instance Method Summary collapse

Methods inherited from Base

depends_on, halted_details, independent!, independent?, #initialize

Constructor Details

This class inherits a constructor from Karafka::Web::Ui::Models::Status::Checks::Base

Instance Method Details

#callStatus::Step

Executes the Pro subscription check.

Returns:

  • (Status::Step)

    success if Pro is enabled, warning otherwise



20
21
22
# File 'lib/karafka/web/ui/models/status/checks/pro_subscription.rb', line 20

def call
  step(::Karafka.pro? ? :success : :warning)
end