Module: Karafka::Web::Pro::Commanding::Handlers::GroupIdExtractor
- Included in:
- Partitions::Listener, Topics::Listener
- Defined in:
- lib/karafka/web/pro/commanding/handlers/group_id_extractor.rb
Overview
Module containing a helper for extracting the consumer group id out of a subscription group, shared by the commanding fetch-loop listeners
Instance Method Summary collapse
-
#group_id_of(subscription_group) ⇒ String
Id of the consumer group the subscription group belongs to.
Instance Method Details
#group_id_of(subscription_group) ⇒ String
Returns id of the consumer group the subscription group belongs to.
41 42 43 |
# File 'lib/karafka/web/pro/commanding/handlers/group_id_extractor.rb', line 41 def group_id_of(subscription_group) subscription_group.group.id end |