Module: Karafka::Web::Pro::Commanding::Matchers
- Defined in:
- lib/karafka/web/pro/commanding/matchers/base.rb,
lib/karafka/web/pro/commanding/matchers/topic.rb,
lib/karafka/web/pro/commanding/matchers/process_id.rb,
lib/karafka/web/pro/commanding/matchers/message_type.rb,
lib/karafka/web/pro/commanding/matchers/partition_id.rb,
lib/karafka/web/pro/commanding/matchers/schema_version.rb,
lib/karafka/web/pro/commanding/matchers/consumer_group_id.rb
Overview
Namespace for individual matcher implementations used by the Matcher class. Each sub-matcher is responsible for checking a single criterion (e.g., consumer_group_id, topic).
Defined Under Namespace
Classes: Base, ConsumerGroupId, MessageType, PartitionId, ProcessId, SchemaVersion, Topic