Class: Karafka::Web::Pro::Ui::App
- Defined in:
- lib/karafka/web/pro/ui/app.rb
Overview
Main Roda Web App that servers all the metrics and stats
Constant Summary
Constants inherited from Ui::Base
Constants included from Ui::Helpers::TailwindHelper
Ui::Helpers::TailwindHelper::TYPES
Constants included from Ui::Helpers::TopicsHelper
Ui::Helpers::TopicsHelper::DEFAULT_LIMIT
Instance Method Summary collapse
-
#features ⇒ Karafka::Web::Pro::Ui::Lib::Features
Features fetcher.
-
#params ⇒ Controllers::Requests::Params
Builds the Pro request params, which add the filtering (search) readers on top of the OSS ones.
Methods included from Helpers::TopicsFilteringHelper
Methods included from Helpers::FilteringHelper
Methods inherited from Ui::Base
Methods included from Ui::Helpers::TailwindHelper
#badge, #link_button, #tailwind_types
Methods included from Ui::Helpers::TopicsHelper
#topics_assignment_label, #topics_assignment_text, #topics_partition_identifier
Methods included from Ui::Helpers::TimeHelper
#human_readable_time, #poll_state_with_change_time_label, #relative_time, #time_with_label
Methods included from Ui::Helpers::SortingHelper
Methods included from Ui::Helpers::PartitionsHelper
#lag_with_label, #lso_risk_state_badge, #lso_risk_state_bg, #normalized_metric, #offset_with_label, #partition_in_sync_brokers, #partition_replica_brokers
Methods included from Ui::Helpers::FormattingHelper
#format_memory, #number_with_delimiter, #object_value_to_s, #truncate
Methods included from Ui::Helpers::BadgesHelper
#kafka_state_badge, #lag_trend_badge, #status_badge, #tags
Methods included from Ui::Helpers::ApplicationHelper
#deep_merge, #empty_state, #icon, #nav_class, #view_title
Methods included from Ui::Helpers::PathsHelper
#action?, #asset_path, #consumer_path, #consumers_path, #explorer_messages_path, #explorer_path, #explorer_topics_path, #flatten_params, #root_path, #scheduled_messages_explorer_path, #topics_path
Instance Method Details
#features ⇒ Karafka::Web::Pro::Ui::Lib::Features
Returns features fetcher.
110 111 112 |
# File 'lib/karafka/web/pro/ui/app.rb', line 110 def features Lib::Features end |
#params ⇒ Controllers::Requests::Params
Builds the Pro request params, which add the filtering (search) readers on top of the OSS ones. Overriding here keeps the filtering param parsing out of the shared params.
74 75 76 |
# File 'lib/karafka/web/pro/ui/app.rb', line 74 def params Controllers::Requests::Params.new(request.params) end |