Class: Karafka::Web::Ui::Models::Status::Checks::ConsumersReports
- Defined in:
- lib/karafka/web/ui/models/status/checks/consumers_reports.rb
Overview
Checks if we can read and operate on the current processes data.
This verifies that the consumers reports can be parsed and loaded into process objects for display in the UI.
Instance Method Summary collapse
-
#call ⇒ Status::Step
Executes the consumers reports check.
Methods inherited from Base
depends_on, halted_details, independent!, independent?, #initialize
Constructor Details
This class inherits a constructor from Karafka::Web::Ui::Models::Status::Checks::Base
Instance Method Details
#call ⇒ Status::Step
Executes the consumers reports check.
Attempts to load all processes from the current state. Caches the result in context for subsequent checks.
22 23 24 25 26 27 |
# File 'lib/karafka/web/ui/models/status/checks/consumers_reports.rb', line 22 def call context.processes ||= Models::Processes.all(context.current_state) step(:success) rescue JSON::ParserError step(:failure) end |